======
cadati
======

.. image:: https://github.com/TUW-GEO/cadati/workflows/ubuntu/badge.svg
   :target: https://github.com/TUW-GEO/cadati/actions/workflows/ubuntu.yml

.. image:: https://github.com/TUW-GEO/cadati/workflows/windows/badge.svg
   :target: https://github.com/TUW-GEO/cadati/actions/workflows/windows.yml

.. image:: https://coveralls.io/repos/github/TUW-GEO/cadati/badge.svg?branch=master
   :target: https://coveralls.io/github/TUW-GEO/cadati?branch=master

.. image:: https://badge.fury.io/py/cadati.svg
    :target: http://badge.fury.io/py/cadati

.. image:: https://readthedocs.org/projects/cadati/badge/?version=latest
   :target: http://cadati.readthedocs.org/

The cadati package provides CAlender, DAte and TIme functions.

Citation
========

.. image:: https://zenodo.org/badge/264928989.svg
   :target: https://zenodo.org/badge/latestdoi/264928989

If you use the software in a publication then please cite it using the Zenodo DOI. Be aware that this badge links to the latest package version.

Please select your specific version at https://doi.org/10.5281/zenodo.3832082 to get the DOI of that version. You should normally always use the DOI for the specific version of your record in citations. This is to ensure that other researchers can access the exact research artefact you used for reproducibility.

You can find additional information regarding DOI versioning at http://help.zenodo.org/#versioning

Contribute
==========

We are happy if you want to contribute. Please raise an issue explaining what is missing or if you find a bug. We will also gladly accept pull requests against our master branch for new features or bug fixes.

Note
====

This project has been set up using PyScaffold 4.5. For details and usage
information on PyScaffold see https://pyscaffold.org/.
